@@ -22,11 +22,11 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 ANTHY_PC= 'anthy'
-PKGDATADIR = '/usr/pkg/share/ibus-anthy'
-LIBEXECDIR = '/usr/pkg/libexec'
-LOCALEDIR = '/usr/pkg/share/locale'
-LAYOUT = 'default'
+PKGDATADIR = '/usr/local/share/ibus-anthy'
+LIBEXECDIR = '/usr/local/libexec'
+LOCALEDIR = '/usr/local/share/locale'
+LAYOUT = 'jp'
 SYMBOL_CHAR = chr(0x3042)
 ICON_PREFERENCE = 'preferences-desktop'
-VERSION = '1.5.15'
+VERSION = '1.5.16'
 DEBUG = False
